@@ -18,6 +18,7 @@ def _get_metric_stat(**kargs):
   p = kargs.get('Period')
   mn = kargs.get('MetricName')
   s = kargs.get('Stat')
+  u = kargs.get('Unit')
   ns = f"AWS/{kargs.get('Namespace')}"
   d = kargs.get('Dimensions')
   et = dt.now()
@@ -45,6 +46,7 @@ def _get_metric_data(**kargs):
   p = kargs.get('Period')
   mn = kargs.get('MetricName')
   s = kargs.get('Stat')
+  u = kargs.get('Unit')
   ns = f"AWS/{kargs.get('Namespace')}"
   d = kargs.get('Dimensions')
   et = dt.now()
@@ -65,7 +67,8 @@ def _get_metric_data(**kargs):
                                            "Dimensions": [d]
                                        },
                                        "Period": p, 
-                                       "Stat": s
+                                       "Stat": s,
+                                       "Unit": u
                                    }
                                   }
                               ]).json;
